@@ -1,4 +1,4 @@
-#' The stochastic approximation principal components can handle data sets that are updated in real time and streaming data.
+#' The stochastic approximation principal component can handle online data sets with highly correlated.
 #'
 #' @param data is a highly correlated online data set
 #' @param m is the number of principal component 
@@ -20,23 +20,16 @@ eig1<-eigen(cov(X[1:n0,]-Xbar))
 lambda<-eig1$values[1:m]       
 V<-eig1$vectors[,1:m]      
 V1<-V
-T<-matrix(rep(0,(m+1)*(m+1)),nrow=(m+1))
 
 for (i in (n0+1):n) {
-Xcenter<-t(X[i,]-Xbar)       
-g<-t(V)%*%t(Xcenter)  
-Xhat<-t(V%*%g)+Xbar          
-h<-t(X[i,]-Xhat)            
-hmao<-norm(h,"2")            
-gamma<-as.numeric(t(h/hmao)%*%t(Xcenter))   
-T[1:m,]<-cbind(((i-1)/i)*diag(lambda)+((i-1)^2/i^3)*g%*%t(g),((i-1)^2/i^3)*gamma*g)
-T[(m+1),]<-cbind(((i-1)^2/i^3)*gamma*t(g),((i-1)^2/i^3)*gamma^2)               
-eig2<-eigen(T)                
-lambda<-eig2$values[1:m]               
-V<-(cbind(V,h/hmao)%*%eig2$vectors)[,1:m]
-Xbar<-((i-1)/i)*Xbar+(1/i)*X[i,]   
+Xbar<-((i-1)/i)*Xbar+(1/i)*X[i,]
+Xcenter<-t(t(X[i,]-Xbar))
+gamma<-1/(i^(0.73))
+V<-V+gamma*Xcenter%*%t(Xcenter)%*%V
+V<-qr.Q(qr(V))
+lambda<- lambda+gamma*(t(V)%*%Xcenter%*%t(Xcenter)%*%V)
 }
-V2<-V[,1:m]
+V2<-V
 Asa<-matrix(0,nrow=p,ncol=m)
 for (j in 1:m){
   Asa[,j]<-sqrt(lambda[j])*V2[,j]
